@@ -14,9 +14,9 @@ use Perinci::Sub::Util qw(err gen_modified_sub);
 require Exporter;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-11-15'; # DATE
+our $DATE = '2021-11-16'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.343'; # VERSION
+our $VERSION = '0.344'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = (
@@ -1604,7 +1604,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.343 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-11-15.
+This document describes version 0.344 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-11-16.
 
 =head1 SYNOPSIS
 
@@ -1686,9 +1686,21 @@ returns the number of working days in the current month:
 
 =head1 DESCRIPTION
 
-This module provides functions to list Indonesian holidays.
+This module provides functions to list Indonesian holidays. There is a
+command-line script interface for this module: L<list-idn-holidays>.
 
-There is a command-line script interface for this module: L<list-id-holidays>.
+Note: Note that sometimes the holiday (as set by law) falls at a different date
+than the actual religious commemoration date. When you use the C<detail> option,
+the C<original_date> key will show you the actual religious date.
+
+Note: it is also possible that multiple (religious, cultural) holidays fall on
+the same national holiday. An example is May 8, 1997 which is commemorated as
+Hijra 1418H as well as Ascension Day. When this happens, the C<holidays> key
+will contain the details of each religious/cultural holiday.
+
+Caveat: aside from national holidays, some provinces sometimes declare their own
+(e.g. governor election day for East Java province, etc). This is currently not
+yet included in this module.
 
 =head1 DEVELOPER NOTES
 
@@ -2452,13 +2464,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Calendar-I
 
 Source repository is at L<https://github.com/perlancar/perl-Calendar-Indonesia-Holiday>.
 
-=head1 SEE ALSO
-
-This API will also be available on GudangAPI, http://gudangapi.com/
-
-Aside from national holidays, some provinces declare their own (e.g. governor
-election day for East Java province, etc).
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
